==> dasu_4.11.jar: edu/northwestern/dasu/dynamic/coordination/UnlimitedDistributedCoordinator.java <==
/**
 * Dasu Project
 *
 * File:         UnlimitedDistributedCoordinator.java
 * RCS:          $Id: ZooKeeperCoordinator.java,v 1.0 Oct 1, 2012 11:14:05 PM mas939 Exp $
 * Description:  UnlimitedDistributedCoordinator class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Oct 1, 2012 at 11:14:05 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.dynamic.coordination
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.dynamic.coordination;

import edu.northwestern.dasu.coordination.DistributedCoordinator;
import edu.northwestern.dasu.measurement.tasks.ProbeTask.ProbeSubTask;
import edu.northwestern.dasu.measurement.types.SourceType;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The UnlimitedDistributedCoordinator class ...
 */
public class UnlimitedDistributedCoordinator extends DistributedCoordinator {

	
	private Boolean isActive = false;
	public Object halt = new Object();
	private boolean terminate = false;
	long schedulerInterval = 10;
	
	public UnlimitedDistributedCoordinator(SourceType engineId,
			String namePrefix) {
		super(engineId, namePrefix, 2.0f);
		isActive = true;
	}

	//an unlimited distributed coordinator
	public void run() {
		
		
		//this is technically not required, run can be empty
		while (isActive) {
		
			synchronized (halt) {
	
				try {				
					halt.wait(schedulerInterval*1000);
				} catch (InterruptedException e) {					
				}	
			}
			
			if (terminate) {		
				return;
			}
		}
		
	}

	@Override
	public boolean schedulable(ProbeSubTask pst) {
		return true;
	}

	@Override
	public void stopCoordinator() {
		isActive = false;
		synchronized(halt) {
			terminate = true;
			halt.notify();
		}		
	}

}

==> dasu_5.1.jar: edu/northwestern/dasu/dynamic/coordination/UnlimitedDistributedCoordinator.java <==
/**
 * Dasu Project
 *
 * File:         UnlimitedDistributedCoordinator.java
 * RCS:          $Id: ZooKeeperCoordinator.java,v 1.0 Oct 1, 2012 11:14:05 PM mas939 Exp $
 * Description:  UnlimitedDistributedCoordinator class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Oct 1, 2012 at 11:14:05 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.dynamic.coordination
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.dynamic.coordination;

import edu.northwestern.cs.aqualab.cattle.jsonsimple.JSONObject;
import edu.northwestern.dasu.coordination.DistributedCoordinator;
import edu.northwestern.dasu.measurement.tasks.ProbeTask.ProbeSubTask;
import edu.northwestern.dasu.measurement.types.SourceType;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The UnlimitedDistributedCoordinator class ...
 */
public class UnlimitedDistributedCoordinator extends DistributedCoordinator {

	
	private Boolean isActive = false;
	public Object halt = new Object();
	private boolean terminate = false;
	long schedulerInterval = 10;
	
	public UnlimitedDistributedCoordinator(SourceType engineId,
			String namePrefix, JSONObject distributedCoordinatorParams) {
		super(engineId, namePrefix, 2.0f);
		isActive = true;
		LOGGER.info("COORDINATION: " + distributedCoordinatorParams);
	}

	//an unlimited distributed coordinator
	public void run() {
		
		//this is technically not required, run can be empty
		while (isActive) {
		
			synchronized (halt) {
	
				try {				
					halt.wait(schedulerInterval*1000);
				} catch (InterruptedException e) {					
				}	
			}
			
			if (terminate) {		
				return;
			}
		}
		
	}

	@Override
	public boolean schedulable(ProbeSubTask pst) {
		return true;
	}

	@Override
	public void stopCoordinator() {
		isActive = false;
		synchronized(halt) {
			terminate = true;
			halt.notify();
		}		
	}

}
